package de.jottyfan.timetrack.spring.note;

import java.util.Arrays;
import java.util.List;

import javax.annotation.security.RolesAllowed;
import javax.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import de.jottyfan.timetrack.db.note.enums.EnumCategory;
import de.jottyfan.timetrack.db.note.enums.EnumNotetype;

/**
 * 
 * @author henkej
 *
 */
@Controller
public class NoteController {
	private static final Logger LOGGER = LogManager.getLogger(NoteController.class);

	private final HttpServletRequest request;

	@Autowired
	private INoteService noteService;

	@Autowired
	public NoteController(HttpServletRequest request) {
		this.request = request;
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/note/list")
	public String getList(Model model) {
		List<NoteBean> list = noteService.getList();
		model.addAttribute("noteList", list);
		return "note/list";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/note/add", method = RequestMethod.GET)
	public String toAdd(Model model) {
		return toItem(null, model);
	}

	@RolesAllowed("timetrack_user")
  @GetMapping("/note/edit/{id}")
	public String toItem(@PathVariable Integer id, Model model) {
		NoteBean bean = noteService.getBean(id);
		if (bean == null) {
			bean = new NoteBean(); // the add case
		}
		model.addAttribute("noteBean", bean);
		model.addAttribute("types", Arrays.asList(EnumNotetype.values()));
		model.addAttribute("categories", Arrays.asList(EnumCategory.values()));
		return "note/item";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/note/upsert", method = RequestMethod.POST)
	public String doUpsert(Model model, @ModelAttribute NoteBean bean) {
		Integer amount = noteService.doUpsert(bean);
		return amount.equals(1) ? getList(model) : toItem(bean.getPk(), model);
	}

	@RolesAllowed("timetrack_user")
	@GetMapping(value = "/note/delete/{id}")
	public String doDelete(@PathVariable Integer id, Model model) {
		Integer amount = noteService.doDelete(id);
		return amount.equals(1) ? getList(model) : toItem(id, model);
	}

}
