package de.jottyfan.timetrack.spring.note.impl;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jooq.DSLContext;
import org.keycloak.KeycloakSecurityContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import de.jottyfan.timetrack.spring.note.INoteService;
import de.jottyfan.timetrack.spring.note.NoteBean;

/**
 * 
 * @author henkej
 *
 */
@Service
@Transactional(transactionManager = "transactionManager")
public class NoteService implements INoteService {
	private static final Logger LOGGER = LogManager.getLogger(NoteService.class);

	@Autowired
	private DSLContext dsl;
	
	@Override
  public String getCurrentUser(HttpServletRequest request) {
		KeycloakSecurityContext ksc = (KeycloakSecurityContext) request.getAttribute(KeycloakSecurityContext.class.getName());
		return ksc == null ? "" : ksc.getIdToken().getPreferredUsername();
	}

	@Override
	public List<NoteBean> getList() {
		try {
			return new NoteGateway(dsl).getAll();
		} catch (Exception e) {
			LOGGER.error(e);
			return new ArrayList<>();
		}
	}

	@Override
	public Integer doUpsert(NoteBean bean) {
		try {
			NoteGateway gw = new NoteGateway(dsl);
			return bean.getPk() == null ? gw.add(bean) : gw.update(bean);
		} catch (Exception e) {
			LOGGER.error(e);
			return 0;
		}
	}

	@Override
	public Integer doDelete(Integer pk) {
		try {
			return new NoteGateway(dsl).delete(pk);
		} catch (Exception e) {
			LOGGER.error(e);
			return 0;
		}
	}

	@Override
	public Integer getAmount() {
		return getList().size();
	}

	@Override
	public NoteBean getBean(Integer id) {
		try {
			return new NoteGateway(dsl).getBean(id);
		} catch (Exception e) {
			LOGGER.error(e);
			return null;
		}
	}
}
