package de.jottyfan.timetrack.modules;

import java.io.InputStream;
import java.util.Properties;

import javax.enterprise.context.RequestScoped;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;

import de.jooqfaces.JooqFacesContext;
import de.jottyfan.timetrack.help.Pages;

/**
 * 
 * @author henkej
 *
 */
@Named
@RequestScoped
public class SessionControl {

	@Inject
	private SessionBean sessionBean;

	private String secretNew1;
	private String secretNew2;

	public String doLogin() {
		SessionModel model = new SessionModel();
		model.doLogin((JooqFacesContext) FacesContext.getCurrentInstance(), sessionBean);
		return Pages.START.get();
	}

	public String doLogout() {
		sessionBean.setLogin(null);
		sessionBean.setSecret(null);
		sessionBean.setForename(null);
		sessionBean.setSurname(null);
		sessionBean.setUsername(null);
		sessionBean.getPrivileges().clear();
		return Pages.START.get();
	}

	public String doChangePassword() {
		if (!secretNew1.equals(secretNew2)) {
			FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on changing password",
					"passwords are not equal");
			FacesContext.getCurrentInstance().addMessage(null, msg);
			return "";
		} else if (new SessionModel().doChangePassword((JooqFacesContext) FacesContext.getCurrentInstance(), secretNew1)) {
			FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_INFO, "successfully changed password",
					"the new password has been saved");
			FacesContext.getCurrentInstance().addMessage(null, msg);
			return Pages.START.get();
		} else {
			FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on changing password",
					"database change was not successful");
			FacesContext.getCurrentInstance().addMessage(null, msg);
			return "";
		}
	}

	/**
	 * get the version from the mainfest file
	 * 
	 * @return the version
	 */
	public String getVersion() {
		FacesContext facesContext = FacesContext.getCurrentInstance();
		try (InputStream is = facesContext.getExternalContext().getResourceAsStream("META-INF/MANIFEST.MF")){
			// from servletcontext
			Properties attributes = new Properties();
			attributes.load(is);
			return attributes.getProperty("Implementation-Version", "no Implementation-Version attribute found in MANIFEST");
		} catch (Exception e) {
			FacesMessage msg = new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on loading the version from the Manifest file", e.getMessage());
			FacesContext.getCurrentInstance().addMessage(null, msg);
			return "?";
		}
	}

	/**
	 * @return the secretNew1
	 */
	public String getSecretNew1() {
		return secretNew1;
	}

	/**
	 * @param secretNew1 the secretNew1 to set
	 */
	public void setSecretNew1(String secretNew1) {
		this.secretNew1 = secretNew1;
	}

	/**
	 * @return the secretNew2
	 */
	public String getSecretNew2() {
		return secretNew2;
	}

	/**
	 * @param secretNew2 the secretNew2 to set
	 */
	public void setSecretNew2(String secretNew2) {
		this.secretNew2 = secretNew2;
	}
}
